@@ -1,4 +1,5 @@
-#include <json.hpp>
+#include <iostream>
+#include <nlohmann/json.hpp>
 
 using json = nlohmann::json;
 
@@ -21,13 +22,27 @@ int main()
     // output changed array
     std::cout << object << '\n';
 
-    // try to write at a nonexisting key
+
+    // exception type_error.304
     try
     {
+        // use at() on a non-object type
+        json str = "I am a string";
+        str.at("the good") = "Another string";
+    }
+    catch (json::type_error& e)
+    {
+        std::cout << e.what() << '\n';
+    }
+
+    // exception out_of_range.401
+    try
+    {
+        // try to write at a nonexisting key
         object.at("the fast") = "il rapido";
     }
-    catch (std::out_of_range& e)
+    catch (json::out_of_range& e)
     {
-        std::cout << "out of range: " << e.what() << '\n';
+        std::cout << e.what() << '\n';
     }
 }
