@@ -1,4 +1,5 @@
-#include <json.hpp>
+#include <iostream>
+#include <nlohmann/json.hpp>
 
 using json = nlohmann::json;
 
@@ -7,7 +8,7 @@ int main()
     // create a JSON object
     json j_object = {{"one", 1}, {"two", 2}};
 
-    // call erase
+    // call erase()
     auto count_one = j_object.erase("one");
     auto count_three = j_object.erase("three");
 
