@@ -1,7 +1,7 @@
 /*
     __ _____ _____ _____
  __|  |   __|     |   | |  JSON for Modern C++ (test suite)
-|  |  |__   |  |  | | | |  version 3.7.3
+|  |  |__   |  |  | | | |  version 3.9.1
 |_____|_____|_____|_|___|  https://github.com/nlohmann/json
 
 Licensed under the MIT License <http://opensource.org/licenses/MIT>.
@@ -91,6 +91,13 @@ TEST_CASE("other constructors and destructor")
             json k(j);
             CHECK(j == k);
         }
+
+        SECTION("binary")
+        {
+            json j = json::binary({1, 2, 3});
+            json k(j);
+            CHECK(j == k);
+        }
     }
 
     SECTION("move constructor")
@@ -167,6 +174,14 @@ TEST_CASE("other constructors and destructor")
             k = j;
             CHECK(j == k);
         }
+
+        SECTION("binary")
+        {
+            json j = json::binary({1, 2, 3});
+            json k;
+            k = j;
+            CHECK(j == k);
+        }
     }
 
     SECTION("destructor")
