@@ -1,7 +1,7 @@
 /*
     __ _____ _____ _____
  __|  |   __|     |   | |  JSON for Modern C++ (test suite)
-|  |  |__   |  |  | | | |  version 3.7.3
+|  |  |__   |  |  | | | |  version 3.9.1
 |_____|_____|_____|_|___|  https://github.com/nlohmann/json
 
 Licensed under the MIT License <http://opensource.org/licenses/MIT>.
@@ -46,20 +46,25 @@ void to_json(json&, pod) noexcept;
 void to_json(json&, pod_bis);
 void from_json(const json&, pod) noexcept;
 void from_json(const json&, pod_bis);
-static json j;
+void to_json(json&, pod) noexcept {}
+void to_json(json&, pod_bis) {}
+void from_json(const json&, pod) noexcept {}
+void from_json(const json&, pod_bis) {}
+
+static json* j = nullptr;
 
 static_assert(noexcept(json{}), "");
-static_assert(noexcept(nlohmann::to_json(j, 2)), "");
-static_assert(noexcept(nlohmann::to_json(j, 2.5)), "");
-static_assert(noexcept(nlohmann::to_json(j, true)), "");
-static_assert(noexcept(nlohmann::to_json(j, test{})), "");
-static_assert(noexcept(nlohmann::to_json(j, pod{})), "");
-static_assert(not noexcept(nlohmann::to_json(j, pod_bis{})), "");
+static_assert(noexcept(nlohmann::to_json(*j, 2)), "");
+static_assert(noexcept(nlohmann::to_json(*j, 2.5)), "");
+static_assert(noexcept(nlohmann::to_json(*j, true)), "");
+static_assert(noexcept(nlohmann::to_json(*j, test{})), "");
+static_assert(noexcept(nlohmann::to_json(*j, pod{})), "");
+static_assert(!noexcept(nlohmann::to_json(*j, pod_bis{})), "");
 static_assert(noexcept(json(2)), "");
 static_assert(noexcept(json(test{})), "");
 static_assert(noexcept(json(pod{})), "");
-static_assert(noexcept(j.get<pod>()), "");
-static_assert(not noexcept(j.get<pod_bis>()), "");
+static_assert(noexcept(j->get<pod>()), "");
+static_assert(!noexcept(j->get<pod_bis>()), "");
 static_assert(noexcept(json(pod{})), "");
 }
 
@@ -79,4 +84,14 @@ TEST_CASE("runtime checks")
         CHECK(std::is_nothrow_copy_constructible<json::out_of_range>::value == std::is_nothrow_copy_constructible<std::runtime_error>::value);
         CHECK(std::is_nothrow_copy_constructible<json::other_error>::value == std::is_nothrow_copy_constructible<std::runtime_error>::value);
     }
+
+    SECTION("silence -Wunneeded-internal-declaration errors")
+    {
+        j = nullptr;
+        json j2;
+        to_json(j2, pod());
+        to_json(j2, pod_bis());
+        from_json(j2, pod());
+        from_json(j2, pod_bis());
+    }
 }
