@@ -1,7 +1,7 @@
 /*
     __ _____ _____ _____
  __|  |   __|     |   | |  JSON for Modern C++ (test suite)
-|  |  |__   |  |  | | | |  version 3.7.3
+|  |  |__   |  |  | | | |  version 3.9.1
 |_____|_____|_____|_|___|  https://github.com/nlohmann/json
 
 Licensed under the MIT License <http://opensource.org/licenses/MIT>.
@@ -34,22 +34,6 @@ using nlohmann::json;
 
 TEST_CASE("pointer access")
 {
-    // create a JSON value with different types
-    json json_types =
-    {
-        {"boolean", true},
-        {
-            "number", {
-                {"integer", 42},
-                {"unsigned", 42u},
-                {"floating-point", 17.23}
-            }
-        },
-        {"string", "Hello, world!"},
-        {"array", {1, 2, 3, 4, 5}},
-        {"null", nullptr}
-    };
-
     SECTION("pointer access to object_t")
     {
         using test_type = json::object_t;
@@ -61,11 +45,11 @@ TEST_CASE("pointer access")
         CHECK(*p1 == value.get<test_type>());
 
         const test_type* p2 = value.get_ptr<const test_type*>();
-        CHECK(p1 == value.get_ptr<const test_type*>());
+        CHECK(p2 == value.get_ptr<const test_type*>());
         CHECK(*p2 == value.get<test_type>());
 
         const test_type* const p3 = value.get_ptr<const test_type* const>();
-        CHECK(p1 == value.get_ptr<const test_type* const>());
+        CHECK(p3 == value.get_ptr<const test_type* const>());
         CHECK(*p3 == value.get<test_type>());
 
         // check if null pointers are returned correctly
@@ -76,6 +60,7 @@ TEST_CASE("pointer access")
         CHECK(value.get_ptr<json::number_integer_t*>() == nullptr);
         CHECK(value.get_ptr<json::number_unsigned_t*>() == nullptr);
         CHECK(value.get_ptr<json::number_float_t*>() == nullptr);
+        CHECK(value.get_ptr<json::binary_t*>() == nullptr);
     }
 
     SECTION("pointer access to const object_t")
@@ -89,11 +74,11 @@ TEST_CASE("pointer access")
         CHECK(*p1 == value.get<test_type>());
 
         const test_type* p2 = value.get_ptr<const test_type*>();
-        CHECK(p1 == value.get_ptr<const test_type*>());
+        CHECK(p2 == value.get_ptr<const test_type*>());
         CHECK(*p2 == value.get<test_type>());
 
         const test_type* const p3 = value.get_ptr<const test_type* const>();
-        CHECK(p1 == value.get_ptr<const test_type* const>());
+        CHECK(p3 == value.get_ptr<const test_type* const>());
         CHECK(*p3 == value.get<test_type>());
 
         // check if null pointers are returned correctly
@@ -104,6 +89,7 @@ TEST_CASE("pointer access")
         CHECK(value.get_ptr<const json::number_integer_t*>() == nullptr);
         CHECK(value.get_ptr<const json::number_unsigned_t*>() == nullptr);
         CHECK(value.get_ptr<const json::number_float_t*>() == nullptr);
+        CHECK(value.get_ptr<const json::binary_t*>() == nullptr);
     }
 
     SECTION("pointer access to array_t")
@@ -117,11 +103,11 @@ TEST_CASE("pointer access")
         CHECK(*p1 == value.get<test_type>());
 
         const test_type* p2 = value.get_ptr<const test_type*>();
-        CHECK(p1 == value.get_ptr<const test_type*>());
+        CHECK(p2 == value.get_ptr<const test_type*>());
         CHECK(*p2 == value.get<test_type>());
 
         const test_type* const p3 = value.get_ptr<const test_type* const>();
-        CHECK(p1 == value.get_ptr<const test_type* const>());
+        CHECK(p3 == value.get_ptr<const test_type* const>());
         CHECK(*p3 == value.get<test_type>());
 
         // check if null pointers are returned correctly
@@ -132,6 +118,7 @@ TEST_CASE("pointer access")
         CHECK(value.get_ptr<json::number_integer_t*>() == nullptr);
         CHECK(value.get_ptr<json::number_unsigned_t*>() == nullptr);
         CHECK(value.get_ptr<json::number_float_t*>() == nullptr);
+        CHECK(value.get_ptr<json::binary_t*>() == nullptr);
     }
 
     SECTION("pointer access to const array_t")
@@ -145,11 +132,11 @@ TEST_CASE("pointer access")
         CHECK(*p1 == value.get<test_type>());
 
         const test_type* p2 = value.get_ptr<const test_type*>();
-        CHECK(p1 == value.get_ptr<const test_type*>());
+        CHECK(p2 == value.get_ptr<const test_type*>());
         CHECK(*p2 == value.get<test_type>());
 
         const test_type* const p3 = value.get_ptr<const test_type* const>();
-        CHECK(p1 == value.get_ptr<const test_type* const>());
+        CHECK(p3 == value.get_ptr<const test_type* const>());
         CHECK(*p3 == value.get<test_type>());
 
         // check if null pointers are returned correctly
@@ -160,6 +147,7 @@ TEST_CASE("pointer access")
         CHECK(value.get_ptr<const json::number_integer_t*>() == nullptr);
         CHECK(value.get_ptr<const json::number_unsigned_t*>() == nullptr);
         CHECK(value.get_ptr<const json::number_float_t*>() == nullptr);
+        CHECK(value.get_ptr<const json::binary_t*>() == nullptr);
     }
 
     SECTION("pointer access to string_t")
@@ -173,11 +161,11 @@ TEST_CASE("pointer access")
         CHECK(*p1 == value.get<test_type>());
 
         const test_type* p2 = value.get_ptr<const test_type*>();
-        CHECK(p1 == value.get_ptr<const test_type*>());
+        CHECK(p2 == value.get_ptr<const test_type*>());
         CHECK(*p2 == value.get<test_type>());
 
         const test_type* const p3 = value.get_ptr<const test_type* const>();
-        CHECK(p1 == value.get_ptr<const test_type* const>());
+        CHECK(p3 == value.get_ptr<const test_type* const>());
         CHECK(*p3 == value.get<test_type>());
 
         // check if null pointers are returned correctly
@@ -188,6 +176,7 @@ TEST_CASE("pointer access")
         CHECK(value.get_ptr<json::number_integer_t*>() == nullptr);
         CHECK(value.get_ptr<json::number_unsigned_t*>() == nullptr);
         CHECK(value.get_ptr<json::number_float_t*>() == nullptr);
+        CHECK(value.get_ptr<json::binary_t*>() == nullptr);
     }
 
     SECTION("pointer access to const string_t")
@@ -201,11 +190,11 @@ TEST_CASE("pointer access")
         CHECK(*p1 == value.get<test_type>());
 
         const test_type* p2 = value.get_ptr<const test_type*>();
-        CHECK(p1 == value.get_ptr<const test_type*>());
+        CHECK(p2 == value.get_ptr<const test_type*>());
         CHECK(*p2 == value.get<test_type>());
 
         const test_type* const p3 = value.get_ptr<const test_type* const>();
-        CHECK(p1 == value.get_ptr<const test_type* const>());
+        CHECK(p3 == value.get_ptr<const test_type* const>());
         CHECK(*p3 == value.get<test_type>());
 
         // check if null pointers are returned correctly
@@ -216,6 +205,7 @@ TEST_CASE("pointer access")
         CHECK(value.get_ptr<const json::number_integer_t*>() == nullptr);
         CHECK(value.get_ptr<const json::number_unsigned_t*>() == nullptr);
         CHECK(value.get_ptr<const json::number_float_t*>() == nullptr);
+        CHECK(value.get_ptr<const json::binary_t*>() == nullptr);
     }
 
     SECTION("pointer access to boolean_t")
@@ -229,11 +219,11 @@ TEST_CASE("pointer access")
         CHECK(*p1 == value.get<test_type>());
 
         const test_type* p2 = value.get_ptr<const test_type*>();
-        CHECK(p1 == value.get_ptr<const test_type*>());
+        CHECK(p2 == value.get_ptr<const test_type*>());
         CHECK(*p2 == value.get<test_type>());
 
         const test_type* const p3 = value.get_ptr<const test_type* const>();
-        CHECK(p1 == value.get_ptr<const test_type* const>());
+        CHECK(p3 == value.get_ptr<const test_type* const>());
         CHECK(*p3 == value.get<test_type>());
 
         // check if null pointers are returned correctly
@@ -244,6 +234,7 @@ TEST_CASE("pointer access")
         CHECK(value.get_ptr<json::number_integer_t*>() == nullptr);
         CHECK(value.get_ptr<json::number_unsigned_t*>() == nullptr);
         CHECK(value.get_ptr<json::number_float_t*>() == nullptr);
+        CHECK(value.get_ptr<json::binary_t*>() == nullptr);
     }
 
     SECTION("pointer access to const boolean_t")
@@ -257,11 +248,11 @@ TEST_CASE("pointer access")
         //CHECK(*p1 == value.get<test_type>());
 
         const test_type* p2 = value.get_ptr<const test_type*>();
-        CHECK(p1 == value.get_ptr<const test_type*>());
+        CHECK(p2 == value.get_ptr<const test_type*>());
         CHECK(*p2 == value.get<test_type>());
 
         const test_type* const p3 = value.get_ptr<const test_type* const>();
-        CHECK(p1 == value.get_ptr<const test_type* const>());
+        CHECK(p3 == value.get_ptr<const test_type* const>());
         CHECK(*p3 == value.get<test_type>());
 
         // check if null pointers are returned correctly
@@ -272,6 +263,7 @@ TEST_CASE("pointer access")
         CHECK(value.get_ptr<const json::number_integer_t*>() == nullptr);
         CHECK(value.get_ptr<const json::number_unsigned_t*>() == nullptr);
         CHECK(value.get_ptr<const json::number_float_t*>() == nullptr);
+        CHECK(value.get_ptr<const json::binary_t*>() == nullptr);
     }
 
     SECTION("pointer access to number_integer_t")
@@ -285,11 +277,11 @@ TEST_CASE("pointer access")
         CHECK(*p1 == value.get<test_type>());
 
         const test_type* p2 = value.get_ptr<const test_type*>();
-        CHECK(p1 == value.get_ptr<const test_type*>());
+        CHECK(p2 == value.get_ptr<const test_type*>());
         CHECK(*p2 == value.get<test_type>());
 
         const test_type* const p3 = value.get_ptr<const test_type* const>();
-        CHECK(p1 == value.get_ptr<const test_type* const>());
+        CHECK(p3 == value.get_ptr<const test_type* const>());
         CHECK(*p3 == value.get<test_type>());
 
         // check if null pointers are returned correctly
@@ -300,6 +292,7 @@ TEST_CASE("pointer access")
         CHECK(value.get_ptr<json::number_integer_t*>() != nullptr);
         CHECK(value.get_ptr<json::number_unsigned_t*>() == nullptr);
         CHECK(value.get_ptr<json::number_float_t*>() == nullptr);
+        CHECK(value.get_ptr<json::binary_t*>() == nullptr);
     }
 
     SECTION("pointer access to const number_integer_t")
@@ -313,11 +306,11 @@ TEST_CASE("pointer access")
         CHECK(*p1 == value.get<test_type>());
 
         const test_type* p2 = value.get_ptr<const test_type*>();
-        CHECK(p1 == value.get_ptr<const test_type*>());
+        CHECK(p2 == value.get_ptr<const test_type*>());
         CHECK(*p2 == value.get<test_type>());
 
         const test_type* const p3 = value.get_ptr<const test_type* const>();
-        CHECK(p1 == value.get_ptr<const test_type* const>());
+        CHECK(p3 == value.get_ptr<const test_type* const>());
         CHECK(*p3 == value.get<test_type>());
 
         // check if null pointers are returned correctly
@@ -328,6 +321,7 @@ TEST_CASE("pointer access")
         CHECK(value.get_ptr<const json::number_integer_t*>() != nullptr);
         CHECK(value.get_ptr<const json::number_unsigned_t*>() == nullptr);
         CHECK(value.get_ptr<const json::number_float_t*>() == nullptr);
+        CHECK(value.get_ptr<const json::binary_t*>() == nullptr);
     }
 
     SECTION("pointer access to number_unsigned_t")
@@ -341,11 +335,11 @@ TEST_CASE("pointer access")
         CHECK(*p1 == value.get<test_type>());
 
         const test_type* p2 = value.get_ptr<const test_type*>();
-        CHECK(p1 == value.get_ptr<const test_type*>());
+        CHECK(p2 == value.get_ptr<const test_type*>());
         CHECK(*p2 == value.get<test_type>());
 
         const test_type* const p3 = value.get_ptr<const test_type* const>();
-        CHECK(p1 == value.get_ptr<const test_type* const>());
+        CHECK(p3 == value.get_ptr<const test_type* const>());
         CHECK(*p3 == value.get<test_type>());
 
         // check if null pointers are returned correctly
@@ -356,6 +350,7 @@ TEST_CASE("pointer access")
         CHECK(value.get_ptr<json::number_integer_t*>() != nullptr);
         CHECK(value.get_ptr<json::number_unsigned_t*>() != nullptr);
         CHECK(value.get_ptr<json::number_float_t*>() == nullptr);
+        CHECK(value.get_ptr<json::binary_t*>() == nullptr);
     }
 
     SECTION("pointer access to const number_unsigned_t")
@@ -369,11 +364,11 @@ TEST_CASE("pointer access")
         CHECK(*p1 == value.get<test_type>());
 
         const test_type* p2 = value.get_ptr<const test_type*>();
-        CHECK(p1 == value.get_ptr<const test_type*>());
+        CHECK(p2 == value.get_ptr<const test_type*>());
         CHECK(*p2 == value.get<test_type>());
 
         const test_type* const p3 = value.get_ptr<const test_type* const>();
-        CHECK(p1 == value.get_ptr<const test_type* const>());
+        CHECK(p3 == value.get_ptr<const test_type* const>());
         CHECK(*p3 == value.get<test_type>());
 
         // check if null pointers are returned correctly
@@ -384,6 +379,7 @@ TEST_CASE("pointer access")
         CHECK(value.get_ptr<const json::number_integer_t*>() != nullptr);
         CHECK(value.get_ptr<const json::number_unsigned_t*>() != nullptr);
         CHECK(value.get_ptr<const json::number_float_t*>() == nullptr);
+        CHECK(value.get_ptr<const json::binary_t*>() == nullptr);
     }
 
     SECTION("pointer access to number_float_t")
@@ -397,11 +393,11 @@ TEST_CASE("pointer access")
         CHECK(*p1 == Approx(value.get<test_type>()));
 
         const test_type* p2 = value.get_ptr<const test_type*>();
-        CHECK(p1 == value.get_ptr<const test_type*>());
+        CHECK(p2 == value.get_ptr<const test_type*>());
         CHECK(*p2 == Approx(value.get<test_type>()));
 
         const test_type* const p3 = value.get_ptr<const test_type* const>();
-        CHECK(p1 == value.get_ptr<const test_type* const>());
+        CHECK(p3 == value.get_ptr<const test_type* const>());
         CHECK(*p3 == Approx(value.get<test_type>()));
 
         // check if null pointers are returned correctly
@@ -412,6 +408,7 @@ TEST_CASE("pointer access")
         CHECK(value.get_ptr<json::number_integer_t*>() == nullptr);
         CHECK(value.get_ptr<json::number_unsigned_t*>() == nullptr);
         CHECK(value.get_ptr<json::number_float_t*>() != nullptr);
+        CHECK(value.get_ptr<json::binary_t*>() == nullptr);
     }
 
     SECTION("pointer access to const number_float_t")
@@ -425,11 +422,11 @@ TEST_CASE("pointer access")
         CHECK(*p1 == Approx(value.get<test_type>()));
 
         const test_type* p2 = value.get_ptr<const test_type*>();
-        CHECK(p1 == value.get_ptr<const test_type*>());
+        CHECK(p2 == value.get_ptr<const test_type*>());
         CHECK(*p2 == Approx(value.get<test_type>()));
 
         const test_type* const p3 = value.get_ptr<const test_type* const>();
-        CHECK(p1 == value.get_ptr<const test_type* const>());
+        CHECK(p3 == value.get_ptr<const test_type* const>());
         CHECK(*p3 == Approx(value.get<test_type>()));
 
         // check if null pointers are returned correctly
@@ -440,5 +437,64 @@ TEST_CASE("pointer access")
         CHECK(value.get_ptr<const json::number_integer_t*>() == nullptr);
         CHECK(value.get_ptr<const json::number_unsigned_t*>() == nullptr);
         CHECK(value.get_ptr<const json::number_float_t*>() != nullptr);
+        CHECK(value.get_ptr<const json::binary_t*>() == nullptr);
+    }
+
+    SECTION("pointer access to const binary_t")
+    {
+        using test_type = const json::binary_t;
+        const json value = json::binary({1, 2, 3});
+
+        // check if pointers are returned correctly
+        test_type* p1 = value.get_ptr<test_type*>();
+        CHECK(p1 == value.get_ptr<test_type*>());
+        CHECK(*p1 == value.get<test_type>());
+
+        const test_type* p2 = value.get_ptr<const test_type*>();
+        CHECK(p2 == value.get_ptr<const test_type*>());
+        CHECK(*p2 == value.get<test_type>());
+
+        const test_type* const p3 = value.get_ptr<const test_type* const>();
+        CHECK(p3 == value.get_ptr<const test_type* const>());
+        CHECK(*p3 == value.get<test_type>());
+
+        // check if null pointers are returned correctly
+        CHECK(value.get_ptr<const json::object_t*>() == nullptr);
+        CHECK(value.get_ptr<const json::array_t*>() == nullptr);
+        CHECK(value.get_ptr<const json::string_t*>() == nullptr);
+        CHECK(value.get_ptr<const json::boolean_t*>() == nullptr);
+        CHECK(value.get_ptr<const json::number_integer_t*>() == nullptr);
+        CHECK(value.get_ptr<const json::number_unsigned_t*>() == nullptr);
+        CHECK(value.get_ptr<const json::number_float_t*>() == nullptr);
+        CHECK(value.get_ptr<const json::binary_t*>() != nullptr);
+    }
+
+    SECTION("pointer access to const binary_t")
+    {
+        using test_type = const json::binary_t;
+        const json value = json::binary({});
+
+        // check if pointers are returned correctly
+        test_type* p1 = value.get_ptr<test_type*>();
+        CHECK(p1 == value.get_ptr<test_type*>());
+        CHECK(*p1 == value.get<test_type>());
+
+        const test_type* p2 = value.get_ptr<const test_type*>();
+        CHECK(p2 == value.get_ptr<const test_type*>());
+        CHECK(*p2 == value.get<test_type>());
+
+        const test_type* const p3 = value.get_ptr<const test_type* const>();
+        CHECK(p3 == value.get_ptr<const test_type* const>());
+        CHECK(*p3 == value.get<test_type>());
+
+        // check if null pointers are returned correctly
+        CHECK(value.get_ptr<const json::object_t*>() == nullptr);
+        CHECK(value.get_ptr<const json::array_t*>() == nullptr);
+        CHECK(value.get_ptr<const json::string_t*>() == nullptr);
+        CHECK(value.get_ptr<const json::boolean_t*>() == nullptr);
+        CHECK(value.get_ptr<const json::number_integer_t*>() == nullptr);
+        CHECK(value.get_ptr<const json::number_unsigned_t*>() == nullptr);
+        CHECK(value.get_ptr<const json::number_float_t*>() == nullptr);
+        CHECK(value.get_ptr<const json::binary_t*>() != nullptr);
     }
 }
